@@ -52,9 +52,6 @@ def parse(html: str, p: Product, include: Sequence = None):
     def should_ship_day():
         return "ship_day_min" in include or "ship_day_max" in include
 
-    def should_sold():
-        return "sold" in include or "sold_url_rel" in include
-
     def should_size():
         return "size_length" in include or "size_width" in include or "size_height" in include
 
@@ -74,7 +71,8 @@ def parse(html: str, p: Product, include: Sequence = None):
     "stock" in include and parse_stock(p, selector=sel)
     should_ship_day() and parse_ship_day(p, selector=sel)
     "ship" in include and parse_ship(p, selector=sel)
-    should_sold() and parse_sold(p, selector=sel)
+    "sold" in include and parse_sold(p, selector=sel)
+    "sold_url_rel" in include and parse_sold_url_rel(p, selector=sel)
     "offers" in include and parse_offers(p, selector=sel)
     "delivery" in include and parse_delivery(p, selector=sel)
     "material" in include and parse_material(p, selector=sel)
@@ -88,7 +86,6 @@ def parse(html: str, p: Product, include: Sequence = None):
     "rank" in include and parse_rank(p, selector=sel)
     should_thumbnail() and parse_thumbnail(p, selector=sel)
     "category" in include and parse_category(p, selector=sel)
-    "currency" in include and parse_currency(p, selector=sel)
     "date_first_avail" in include and parse_date_first_avail(p, selector=sel)
 
 
@@ -263,8 +260,23 @@ def parse_ship(p: Product, selector: parsel.Selector = None):
 
 
 def parse_sold(p: Product, selector: parsel.Selector = None):
-    p.sold = selector.xpath("//a[@id='sellerProfileTriggerId']/text()").get()
-    p.sold_url_rel = selector.xpath("//a[@id='sellerProfileTriggerId']/@href").get()
+    sold = selector.xpath("//a[@id='sellerProfileTriggerId']/text()").get()
+    sold = sold or selector.xpath(
+        "normalize-space(string(//div[@id='merchant-info']))"
+    ).re_first(r"Ships from and sold by (.+)\.")
+    if sold is None:
+        p.sold = None
+    else:
+        p.sold = sold
+
+
+def parse_sold_url_rel(p: Product, selector: parsel.Selector = None):
+    sold_url_rel = selector.xpath("//a[@id='sellerProfileTriggerId']/@href").get()
+    sold_url_rel = sold_url_rel or selector.xpath("//div[@id='merchant-info']/a/@href").get()
+    if sold_url_rel is None:
+        p.sold_url_rel = None
+    else:
+        p.sold_url_rel = sold_url_rel
 
 
 def parse_offers(p: Product, selector: parsel.Selector = None):
@@ -272,9 +284,10 @@ def parse_offers(p: Product, selector: parsel.Selector = None):
         "//div[@id='olpLinkWidget_feature_div']//div[@class='olp-text-box']/span[1]/text()"
     ).get()
     if offers is None:
-        p.offers = 0
-    else:
-        p.offers: Union[int, None] = parse_number(offers)
+        p.offers = None
+        return
+
+    p.offers = parse_number(offers)
 
 
 def parse_delivery(p: Product, selector: parsel.Selector = None):
@@ -465,10 +478,6 @@ def parse_category(p: Product, selector: parsel.Selector = None):
         p.category = category
 
 
-def parse_currency(p: Product, selector: parsel.Selector = None):
-    p.currency = None
-
-
 def parse_date_first_avail(p: Product, selector: parsel.Selector = None):
     date = product_details_detail_bullets(selector, "Date First Available")
     date = date or selector.xpath(
